@@ -20,7 +20,6 @@ import os
 import posixpath
 import sys
 import logging
-import urllib
 
 import genshi
 
@@ -71,7 +70,7 @@ class WebalbumPage(genfile.WebalbumFile):
                 osize_info['link'] = self._add_size_qualifier(filename
                                                               + '.html',
                                                               osize_name)
-                osize_info['link'] = self.url_quote(osize_info['link'])
+                osize_info['link'] = pathutils.url_quote(osize_info['link'])
             osize_index_links.append(osize_info)
 
         return osize_index_links
@@ -85,9 +84,6 @@ class WebalbumPage(genfile.WebalbumFile):
     def _do_not_escape(self, value):
         return genshi.core.Markup(value)
 
-    def url_quote(self, url):
-        return urllib.quote(url.encode(sys.getfilesystemencoding()), safe=':/#')
-
     UNIT_PREFIXES = (('T', 2 ** 40), ('G', 2 ** 30), ('M', 2 ** 20), ('K', 2 ** 10),)
 
     def format_filesize(self, size_bytes):
@@ -126,8 +122,8 @@ class WebalbumBrowsePage(WebalbumPage):
 
     def build(self):
         page_rel_path = self.rel_path(self.dir.flattening_dir)
-        logging.info(_("  XHTML %s") % page_rel_path)
-        logging.debug("(%s)" % self.page_path)
+        logging.info(_("  XHTML %s"), page_rel_path)
+        logging.debug("(%s)", self.page_path)
 
         tpl_values = self.init_tpl_values()
 
@@ -159,7 +155,7 @@ class WebalbumBrowsePage(WebalbumPage):
             tpl_values['feed_url'] = os.path.relpath(self.dir.feed.path,
                                                      self.dir.path)
             tpl_values['feed_url'] = pathutils.url_path(tpl_values['feed_url'])
-            tpl_values['feed_url'] = self.url_quote(tpl_values['feed_url'])
+            tpl_values['feed_url'] = pathutils.url_quote(tpl_values['feed_url'])
         else:
             tpl_values['feed_url'] = None
 
@@ -173,7 +169,7 @@ class WebalbumBrowsePage(WebalbumPage):
             else:
                 tpl_values['original_link'] = self.media.filename
             tpl_values['original_link'] =\
-                self.url_quote(tpl_values['original_link'])
+                pathutils.url_quote(tpl_values['original_link'])
 
         self.add_extra_vals(tpl_values)
 
@@ -210,7 +206,7 @@ class WebalbumIndexPage(WebalbumPage):
                         # checks when dir is flattenend).
                         dir.add_dependency(media.browse_pages[size_name])
             else:
-                logging.warning(_("  Size '%s' is not available in '%s' due to configuration: medias won't be shown on index.") % (size_name, dir.path))
+                logging.warning(_("  Size '%s' is not available in '%s' due to configuration: medias won't be shown on index."), size_name, dir.path)
 
             if self.dir.dirzip is not None:
                 self.add_dependency(self.dir.dirzip)
@@ -250,7 +246,7 @@ class WebalbumIndexPage(WebalbumPage):
                 filename = self._get_paginated_name(onum)
                 onum_info['link'] = self._add_size_qualifier(filename + '.html',
                                                              self.size_name)
-                onum_info['link'] = self.url_quote(onum_info['link'])
+                onum_info['link'] = pathutils.url_quote(onum_info['link'])
             onum_index_links.append(onum_info)
 
         return onum_index_links
@@ -263,8 +259,8 @@ class WebalbumIndexPage(WebalbumPage):
         return subgal_links
 
     def build(self):
-        logging.info(_("  XHTML %s") % os.path.basename(self.page_path))
-        logging.debug("(%s)" % self.page_path)
+        logging.info(_("  XHTML %s"), os.path.basename(self.page_path))
+        logging.debug("(%s)", self.page_path)
 
         values = self.init_tpl_values()
 
@@ -305,7 +301,7 @@ class WebalbumIndexPage(WebalbumPage):
             values['feed_url'] = os.path.relpath(self.dir.feed.path,
                                                  self.dir.path)
             values['feed_url'] = pathutils.url_path(values['feed_url'])
-            values['feed_url'] = self.url_quote(values['feed_url'])
+            values['feed_url'] = pathutils.url_quote(values['feed_url'])
         else:
             values['feed_url'] = None
 
@@ -354,8 +350,8 @@ class WebalbumFeed(make.FileMakeObject):
                             webalbumdir.source_dir.get_mtime())
 
     def build(self):
-        logging.info(_("FEED %s") % os.path.basename(self.path))
-        logging.debug("(%s)" % self.path)
+        logging.info(_("FEED %s"), os.path.basename(self.path))
+        logging.debug("(%s)", self.path)
         self.feed.dump(self.path)
 
 
@@ -378,8 +374,8 @@ class SharedFileTemplate(make.FileMakeObject):
         self.add_file_dependency(shared_tpl_name)
 
     def build(self):
-        logging.info(_("TPL %%SHAREDDIR%%/%s") % os.path.basename(self.path))
-        logging.debug("(%s)" % self.path)
+        logging.info(_("TPL %%SHAREDDIR%%/%s"), os.path.basename(self.path))
+        logging.debug("(%s)", self.path)
         self.tpl.dump(self.tpl_vars, self.path)
 
 
