@@ -1,3 +1,5 @@
+# coding=utf-8
+#
 # Lazygal, a lazy static web gallery generator.
 # Copyright (C) 2011-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
@@ -81,6 +83,15 @@ class TestPathutils(LazygalTest):
         self.assertEqual(url_path('..\\Lazygal\\Lazygal.exe', ntpath),
                          '../Lazygal/Lazygal.exe')
 
+    def test_url_quote(self):
+        self.assertEqual(url_quote('http://host:8080/~user/album/'),
+                         'http://host:8080/%7Euser/album/')
+        self.assertEqual(url_quote('https://host/~user/album/'),
+                         'https://host/%7Euser/album/')
+        self.assertEqual(url_quote(u'/albumé/'), '/album%C3%A9/')
+        self.assertEqual(url_quote('filter: user/'), 'filter%3A%20user/')
+        self.assertEqual(url_quote('index.html', 'id'), 'index.html#id')
+
 
 if __name__ == '__main__':
     unittest.main()
